==> genometools-1.2.0.tar.gz: genometools-1.2.0/src/match/encseq-specialsrank-priv.h <==
/*
  Copyright (c) 2007 Thomas Jahns <Thomas.Jahns@gmx.net>
  Copyright (c) 2007 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef ENCSEQ_SPECIALSRANK_PRIV_H
#define ENCSEQ_SPECIALSRANK_PRIV_H

#include "match/encseq-specialsrank.h"

typedef Seqpos (*RankReportFunc)(const SpecialsRankLookup *ranker,
                                 Seqpos pos);

struct specialsRankLookup
{
  RankReportFunc rankFunc;
  const Encodedsequence *encseq;
  union
  {
    struct specialsRankTable
    {
      Encodedsequencescanstate *scanState;
      Seqpos *rankSumSamples, numSamples, sampleInterval;
      Readmode readmode;
      unsigned sampleIntervalLog2;
    } sampleTable;
    Seqpos lastSeqPos;
  } implementationData;
};

static inline Seqpos
specialsRank(const SpecialsRankLookup *ranker, Seqpos pos)
{
  return ranker->rankFunc(ranker, pos);
}

#endif

==> genometools-1.3.5.tar.gz: genometools-1.3.5/src/match/encseq-specialsrank-priv.h <==
/*
  Copyright (c) 2007 Thomas Jahns <Thomas.Jahns@gmx.net>
  Copyright (c) 2007 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef ENCSEQ_SPECIALSRANK_PRIV_H
#define ENCSEQ_SPECIALSRANK_PRIV_H

#include "match/encseq-specialsrank.h"

typedef unsigned long (*RankReportFunc)(const SpecialsRankLookup *ranker,
                                 unsigned long pos);

struct specialsRankLookup
{
  RankReportFunc rankFunc;
  const GtEncseq *encseq;
  union
  {
    struct specialsRankTable
    {
      GtEncseqReader *scanState;
      unsigned long *rankSumSamples, numSamples, sampleInterval;
      GtReadmode readmode;
      unsigned sampleIntervalLog2;
    } sampleTable;
    unsigned long lastSeqPos;
  } implementationData;
};

static inline unsigned long
specialsRank(const SpecialsRankLookup *ranker, unsigned long pos)
{
  return ranker->rankFunc(ranker, pos);
}

#endif
